.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`util`
===================
.. automodule:: skimage.util

.. currentmodule:: skimage.util
.. autosummary::

   skimage.util.apply_parallel
   skimage.util.compare_images
   skimage.util.crop
   skimage.util.dtype_limits
   skimage.util.img_as_bool
   skimage.util.img_as_float
   skimage.util.img_as_float32
   skimage.util.img_as_float64
   skimage.util.img_as_int
   skimage.util.img_as_ubyte
   skimage.util.img_as_uint
   skimage.util.invert
   skimage.util.map_array
   skimage.util.montage
   skimage.util.pad
   skimage.util.random_noise
   skimage.util.regular_grid
   skimage.util.regular_seeds
   skimage.util.unique_rows
   skimage.util.view_as_blocks
   skimage.util.view_as_windows



apply_parallel
--------------

.. autofunction:: skimage.util.apply_parallel


.. include:: skimage.util.apply_parallel.examples

compare_images
--------------

.. autofunction:: skimage.util.compare_images


.. include:: skimage.util.compare_images.examples

crop
----

.. autofunction:: skimage.util.crop


.. include:: skimage.util.crop.examples

dtype_limits
------------

.. autofunction:: skimage.util.dtype_limits


.. include:: skimage.util.dtype_limits.examples

img_as_bool
-----------

.. autofunction:: skimage.util.img_as_bool


.. include:: skimage.util.img_as_bool.examples

img_as_float
------------

.. autofunction:: skimage.util.img_as_float


.. include:: skimage.util.img_as_float.examples

img_as_float32
--------------

.. autofunction:: skimage.util.img_as_float32


.. include:: skimage.util.img_as_float32.examples

img_as_float64
--------------

.. autofunction:: skimage.util.img_as_float64


.. include:: skimage.util.img_as_float64.examples

img_as_int
----------

.. autofunction:: skimage.util.img_as_int


.. include:: skimage.util.img_as_int.examples

img_as_ubyte
------------

.. autofunction:: skimage.util.img_as_ubyte


.. include:: skimage.util.img_as_ubyte.examples

img_as_uint
-----------

.. autofunction:: skimage.util.img_as_uint


.. include:: skimage.util.img_as_uint.examples

invert
------

.. autofunction:: skimage.util.invert


.. include:: skimage.util.invert.examples

map_array
---------

.. autofunction:: skimage.util.map_array


.. include:: skimage.util.map_array.examples

montage
-------

.. autofunction:: skimage.util.montage


.. include:: skimage.util.montage.examples

pad
---

.. autofunction:: skimage.util.pad


.. include:: skimage.util.pad.examples

random_noise
------------

.. autofunction:: skimage.util.random_noise


.. include:: skimage.util.random_noise.examples

regular_grid
------------

.. autofunction:: skimage.util.regular_grid


.. include:: skimage.util.regular_grid.examples

regular_seeds
-------------

.. autofunction:: skimage.util.regular_seeds


.. include:: skimage.util.regular_seeds.examples

unique_rows
-----------

.. autofunction:: skimage.util.unique_rows


.. include:: skimage.util.unique_rows.examples

view_as_blocks
--------------

.. autofunction:: skimage.util.view_as_blocks


.. include:: skimage.util.view_as_blocks.examples

view_as_windows
---------------

.. autofunction:: skimage.util.view_as_windows


.. include:: skimage.util.view_as_windows.examples

